@@ -2,7 +2,7 @@
  * vinagre-utils.h
  * This file is part of vinagre
  *
- * Copyright (C) 2007,2008 - Jonh Wendell <wendell@bani.com.br>
+ * Copyright (C) 2007,2008,2009 - Jonh Wendell <wendell@bani.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 #include <gtk/gtk.h>
 #include <glib.h>
+#include "vinagre-plugin.h"
 
 /* useful macro */
 #define GBOOLEAN_TO_POINTER(i) ((gpointer) ((i) ? 2 : 1))
@@ -45,7 +46,7 @@ void		vinagre_utils_toggle_widget_visible	(GtkWidget *widget);
 
 const gchar	*vinagre_utils_get_ui_filename		(void);
 const gchar	*vinagre_utils_get_ui_xml_filename	(void);
-GtkBuilder	*vinagre_utils_get_builder		(void);
+GtkBuilder	*vinagre_utils_get_builder		(VinagrePlugin *plugin, const gchar *filename);
 
 gchar		*vinagre_utils_escape_underscores	(const gchar *text,
 							 gssize      length);
@@ -58,12 +59,29 @@ void		vinagre_utils_get_current_viewport	(GdkScreen    *screen,
 							 gint         *x,
 							 gint         *y);
 
-void		vinagre_utils_help_contents		(GtkWindow *window);
+void		vinagre_utils_help_contents		(GtkWindow *window, const gchar *section);
 void		vinagre_utils_help_about		(GtkWindow *window);
 
 gboolean	vinagre_utils_parse_boolean		(const gchar* value);
 
 GtkWidget      *vinagre_gtk_button_new_with_stock_icon   (const gchar *label,
                                                          const gchar *stock_id);
+
+gboolean	vinagre_utils_ask_question		(GtkWindow  *parent,
+							 const char *message,
+							 char       **choices,
+							 int        *choice);
+
+gboolean	vinagre_utils_ask_credential		(GtkWindow *parent,
+							 gchar *kind,
+							 gchar *host,
+							 gboolean need_username,
+							 gboolean need_password,
+							 gchar **username,
+							 gchar **password,
+							 gboolean *save_in_keyring);
+
+gboolean	vinagre_utils_create_dir		(const gchar *filename, GError **error);
+
 #endif  /* __VINAGRE_UTILS_H__  */
 /* vim: set ts=8: */
